@@ -43,7 +43,7 @@ class Client():
     logger.info(response.text)
     return response.text
 
-  def get(self, get, url='/', data={}):
+  def get(self, url='/', data={}):
     querystring = self.token
 
     payload = json.dumps(data).encode('utf-8')
