@@ -139,7 +139,9 @@ def helm3(command, path="C:\\ProgramData\\chocolatey\\bin\\helm.exe"):
     return data
 
 def cli(cmd):
-    return os.system
+    stream = os.popen(cmd)
+    data = stream.read()
+    return data
 
 
 def helm_pull(chart_name, chart_version=None):
